@echo off

:: TSSI RLM Quick Start Batch File
:: Helps with Floating License installation and Debug

:: Check that we have launched from a command console
if %0 == "%~0" @goto :RUNFROMCMDLINE

:: Check that we have the TSSI RLM utility programs
if not EXIST rlm.exe @goto :MISSINGRLM
if not EXIST rlmutil.exe @goto :MISSINGRLMUTIL

:: Determine number of command line arguments and cache in array
set argCount=0
for %%x in (%*) do (
  set /A argCount+=1
)
REM echo Number of processed arguments: %argCount%

:: Check command line arguments
if "%argCount%" == "0" @goto :NOARGUMENTS
if not "%argCount%" == "1" @goto :TOOMANYARGUMENTS
set operationMode=%1
REM echo Operational mode is %operationMode%

:: Discover license file (.lic extension) in CWD. Script assumes only one file per directory
set licCount=0
for %%x in (*.lic) do (
  set /A licCount+=1
  set licFile=%%x
)

REM echo Number of License Files found: %licCount%
REM echo Last License File found: %licFile%

if /I "%operationMode%" == "start"          @goto :STARTRLM
if /I "%operationMode%" == "stop"           @goto :STOPRLM
if /I "%operationMode%" == "serviceStart"   @goto :STARTSERVICE
if /I "%operationMode%" == "serviceStop"    @goto :STOPSERVICE

goto:OPMODENOTKNOWN

:STARTRLM
if "%licCount%" == "0" @goto :NOLICENSEFILES
if not "%licCount%" == "1" @goto :TOOMANYLICENSEFILES
start rlm -c %licFile%
goto:EXITSCRIPT

:STOPRLM
if "%licCount%" == "0" @goto :NOLICENSEFILES
if not "%licCount%" == "1" @goto :TOOMANYLICENSEFILES
rlmutil.exe rlmdown tssi -q
rlmutil.exe rlmdown RLM -q
goto:EXITSCRIPT

:STARTSERVICE
if "%licCount%" == "0" @goto :NOLICENSEFILES
if not "%licCount%" == "1" @goto :TOOMANYLICENSEFILES
:: Check that we are elevated
net session >nul 2>&1
if not "%ERRORLEVEL%" == "0" @goto :NOTADMIN
echo Registering tssirlm service...
rlm -install_service -service_name tssirlm -dlog +%cd%\tssi_rlmd.log 
if not "%ERRORLEVEL%" == "0" @goto :EXITSCRIPT
echo Starting tssirlm service...
sc start tssirlm
if not "%ERRORLEVEL%" == "0" @goto :EXITSCRIPT
echo TSSI RLM service started. Log file is: +%cd%\tssi_rlmd.log
echo If WaveMakerPlus is unable to acquire license, reboot PC and retry
goto:EXITSCRIPT

:STOPSERVICE
:: Check that we are elevated
net session >nul 2>&1
if not "%ERRORLEVEL%" == "0" @goto :NOTADMIN
echo Stopping tssirlm service...
sc stop tssirlm
echo Deleting tssirlm service...
sc delete tssirlm
if not "%ERRORLEVEL%" == "0" @goto :EXITSCRIPT
echo TSSI RLM service stopped and deleted. 
goto:EXITSCRIPT

:: ==========================================================

:RUNFROMCMDLINE
    echo Batch file must be operated from command line
    goto:USAGE

:NOARGUMENTS
    echo Error: Operation Mode must be specified on command line
    goto:USAGE

:TOOMANYARGUMENTS
    echo Error: Too many arguments specified on command line
    goto:USAGE

:OPMODENOTKNOWN
    echo Error: Specified operating mode not recognized 
    goto:USAGE

:TOOMANYLICENSEFILES
    echo Error: Too many .lic license files found in %cd%
    echo Ensure only one .lic file should be in %cd%
    goto:EXITSCRIPT

:NOLICENSEFILES
    echo Error: No .lic license files found in %cd%
    goto:EXITSCRIPT

:NOTADMIN
    echo Error: Command window is not elevated to adminstrator
    echo Command window needs to be elevated to start service 
    goto:EXITSCRIPT

:MISSINGRLM
    echo Error: Could not find executable rlm.exe
    echo Command window needs to be directory containing file or file needs to be in PATH
    goto:EXITSCRIPT

:MISSINGRLMUTIL
    echo Error: Could not find executable rlmutil.exe
    echo Command window needs to be directory containing file or file needs to be in PATH
    goto:EXITSCRIPT

:USAGE
    set "commandLine=Usage: %0 < start | stop | serviceStart | serviceStop >"
    setlocal EnableDelayedExpansion
    echo !commandLine!
    pause
    goto:EXITSCRIPT

:EXITSCRIPT
